@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2023, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -21,6 +21,9 @@
 from functools import wraps
 from typing import Callable
 
+EOREADER_NAME = "eoreader"
+DATETIME_FMT = "%Y%m%dT%H%M%S"
+
 try:
     from methodtools import lru_cache
 
@@ -32,15 +35,6 @@ try:
 
         return wrapper
 
-    def cached_property(func: Callable) -> property:
-        @lru_cache()
-        @property
-        @wraps(func)
-        def wrapper(*args, **kwargs):
-            return func(*args, **kwargs)
-
-        return wrapper
-
 except ImportError:
     print(
         "WARNING!\n"
@@ -58,15 +52,6 @@ except ImportError:
 
         return wrapper
 
-    def cached_property(func: Callable) -> property:
-        @property
-        @lru_cache(maxsize=None)
-        @wraps(func)
-        def wrapper(*args, **kwargs):
-            return func(*args, **kwargs)
-
-        return wrapper
-
 
 from .__meta__ import (
     __author__,
