@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2023, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -33,6 +33,7 @@ import spyndex
 import xarray as xr
 from sertit import rasters
 
+from eoreader import EOREADER_NAME
 from eoreader.bands.band_names import (
     BLUE,
     CA,
@@ -48,7 +49,6 @@ from eoreader.bands.band_names import (
     SpectralBandNames,
 )
 from eoreader.bands.mappings import EOREADER_TO_SPYNDEX_DICT, SPYNDEX_TO_EOREADER_DICT
-from eoreader.utils import EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 np.seterr(divide="ignore", invalid="ignore")
@@ -130,9 +130,12 @@ def compute_index(index: str, bands: dict, **kwargs) -> xr.DataArray:
     """
 
     def _compute_params(_bands, **_kwargs):
-        prms = {
-            EOREADER_TO_SPYNDEX_DICT[key]: value.data for key, value in _bands.items()
-        }
+        prms = {}
+        for key, value in _bands.items():
+            try:
+                prms[EOREADER_TO_SPYNDEX_DICT[key]] = value.data
+            except KeyError:
+                pass
         prms.update(_kwargs)
 
         return prms
