@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2023, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -36,7 +36,7 @@ from rasterio.enums import Resampling
 from sertit import files, rasters, rasters_rio, xml
 from sertit.misc import ListEnum
 
-from eoreader import cache, utils
+from eoreader import DATETIME_FMT, EOREADER_NAME, cache, utils
 from eoreader.bands import (
     ALL_CLOUDS,
     BLUE,
@@ -66,7 +66,7 @@ from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products import OpticalProduct
 from eoreader.products.optical.optical_product import RawUnits
 from eoreader.stac import ASSET_ROLE, BT, GSD, ID, NAME, WV_MAX, WV_MIN
-from eoreader.utils import DATETIME_FMT, EOREADER_NAME, simplify
+from eoreader.utils import simplify
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
@@ -163,9 +163,7 @@ class HlsProduct(OpticalProduct):
         return 30.0
 
     def open_mask(
-        self,
-        resolution: float = None,
-        size: Union[list, tuple] = None,
+        self, resolution: float = None, size: Union[list, tuple] = None, **kwargs
     ) -> Union[xr.DataArray, None]:
         """
         Open a HLS Fmask
@@ -187,12 +185,11 @@ class HlsProduct(OpticalProduct):
             size=size,
             resampling=Resampling.nearest,  # Nearest to keep the flags
             masked=False,
+            **kwargs,
         ).astype(np.uint8)
 
     def _load_nodata(
-        self,
-        resolution: float = None,
-        size: Union[list, tuple] = None,
+        self, resolution: float = None, size: Union[list, tuple] = None, **kwargs
     ) -> Union[xr.DataArray, None]:
         """
         Load nodata (unimaged pixels) as a numpy array.
@@ -209,7 +206,7 @@ class HlsProduct(OpticalProduct):
             Union[xarray.DataArray, None]: Nodata array
 
         """
-        fmask = self.open_mask()
+        fmask = self.open_mask(**kwargs)
         nodata = fmask.copy(
             data=np.where(fmask == self._mask_nodata, 1, 0).astype(np.uint8)
         )
@@ -945,7 +942,7 @@ class HlsProduct(OpticalProduct):
 
         if bands:
             # Open Fmask
-            fmask = self.open_mask(resolution, size)
+            fmask = self.open_mask(resolution, size, **kwargs)
 
             # Don't use load_nodata in order not to load a 2nd time fmask
             nodata = np.where(fmask == self._mask_nodata, 1, 0)
