@@ -342,14 +342,14 @@ class OpticalProduct(Product):
                     LOGGER.debug(f"Converting {band.name} to reflectance")
                     band_arr = self._to_reflectance(band_arr, band_path, band)
 
-                    b_min = band_arr.min().data
-                    if b_min < 0:
-                        LOGGER.debug(
-                            f"Reflectance array has negative values ({b_min} < 0): clipping negative reflectances to 0."
-                        )
-                        # Negative reflectances should be discarded: https://labo.obs-mip.fr/multitemp/can-surface-reflectance-be-negative
-                        # NB: Reflectances > 1 are valid, see https://forum.step.esa.int/t/toa-range-in-sentinel-2-images-between-0-an-1/3168
-                        band_arr = band_arr.clip(min=0, keep_attrs=True)
+                    # b_min = band_arr.min().data
+                    # if b_min < 0:
+                    #     LOGGER.debug(
+                    #         f"Reflectance array has negative values ({b_min} < 0): clipping negative reflectances to 0."
+                    #     )
+                    # Negative reflectances should be discarded: https://labo.obs-mip.fr/multitemp/can-surface-reflectance-be-negative
+                    # NB: Reflectances > 1 are valid, see https://forum.step.esa.int/t/toa-range-in-sentinel-2-images-between-0-an-1/3168
+                    band_arr = band_arr.clip(min=0, keep_attrs=True)
 
                 # Write on disk
                 try:
@@ -445,7 +445,11 @@ class OpticalProduct(Product):
             mask = np.expand_dims(mask, axis=0)
 
         # Set masked values to nodata
-        return band_arr.copy(data=np.where(mask == 0, band_arr, np.nan))
+        band_arr_nodata = band_arr.where(mask == 0)
+
+        # Where sadly drops the encoding dict...
+        band_arr_nodata.rio.update_encoding(band_arr.encoding, inplace=True)
+        return band_arr_nodata
 
     @abstractmethod
     @cache
