@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2023, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -33,6 +33,7 @@ from cloudpathlib import CloudPath
 from sertit import files
 from sertit.misc import ListEnum
 
+from eoreader import DATETIME_FMT, EOREADER_NAME
 from eoreader.bands import (
     BLUE,
     GREEN,
@@ -46,7 +47,6 @@ from eoreader.bands import (
 from eoreader.exceptions import InvalidProductError
 from eoreader.products.optical.planet_product import PlanetProduct
 from eoreader.stac import GSD, ID, NAME, WV_MAX, WV_MIN
-from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
