@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2023, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -41,7 +41,7 @@ from sertit import files, rasters, vectors
 from sertit.misc import ListEnum
 from shapely.geometry import box
 
-from eoreader import cache, utils
+from eoreader import DATETIME_FMT, EOREADER_NAME, cache, utils
 from eoreader.bands import (
     ALL_CLOUDS,
     BLUE,
@@ -70,7 +70,7 @@ from eoreader.products import OpticalProduct
 from eoreader.products.optical.optical_product import RawUnits
 from eoreader.products.product import OrbitDirection
 from eoreader.stac import CENTER_WV, FWHM, GSD, ID, NAME
-from eoreader.utils import DATETIME_FMT, EOREADER_NAME, simplify
+from eoreader.utils import simplify
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
@@ -679,7 +679,9 @@ class S2Product(OpticalProduct):
                                     out_ds.transform = tf
 
         except errors.RasterioIOError as ex:
-            if str(path).endswith("jp2") or str(path).endswith("tif"):
+            if (
+                str(path).endswith("jp2") or str(path).endswith("tif")
+            ) and path.exists():
                 raise InvalidProductError(f"Corrupted file: {path}") from ex
             else:
                 raise ex
@@ -1055,7 +1057,10 @@ class S2Product(OpticalProduct):
         """
         # Get detector footprint to deduce the outside nodata
         nodata = self._open_mask_gt_4_0(
-            S2Jp2Masks.FOOTPRINT, band, size=(band_arr.rio.width, band_arr.rio.height)
+            S2Jp2Masks.FOOTPRINT,
+            band,
+            size=(band_arr.rio.width, band_arr.rio.height),
+            **kwargs,
         ).data
 
         nodata = np.where(nodata == 0, 1, 0).astype(np.uint8)
@@ -1073,6 +1078,7 @@ class S2Product(OpticalProduct):
                 size=(band_arr.rio.width, band_arr.rio.height),
                 indexes=[3, 4, 5, 6, 8],
                 masked=False,
+                **kwargs,
             )
             .astype(np.uint8)
             .data
@@ -1142,7 +1148,10 @@ class S2Product(OpticalProduct):
         """
         # Get detector footprint to deduce the outside nodata
         nodata = self._open_mask_gt_4_0(
-            S2Jp2Masks.FOOTPRINT, band, size=(band_arr.rio.width, band_arr.rio.height)
+            S2Jp2Masks.FOOTPRINT,
+            band,
+            size=(band_arr.rio.width, band_arr.rio.height),
+            **kwargs,
         ).data
 
         nodata = np.where(nodata == 0, 1, 0).astype(np.uint8)
@@ -1379,7 +1388,7 @@ class S2Product(OpticalProduct):
 
         if bands:
             cloud_vec = self._open_mask_gt_4_0(
-                S2Jp2Masks.CLOUDS, "00", resolution=resolution, size=size
+                S2Jp2Masks.CLOUDS, "00", resolution=resolution, size=size, **kwargs
             ).astype(np.uint8)
 
             for band in bands:
