@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2023, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -31,9 +31,9 @@ import xarray as xr
 from cloudpathlib import CloudPath
 from lxml import etree
 from rasterio.enums import Resampling
-from sertit import files, rasters, rasters_rio, vectors
+from sertit import files, rasters, vectors
 
-from eoreader import cache, utils
+from eoreader import DATETIME_FMT, EOREADER_NAME, cache, utils
 from eoreader.bands import (
     ALL_CLOUDS,
     BLUE,
@@ -58,7 +58,7 @@ from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products import OpticalProduct, S2ProductType
 from eoreader.products.optical.optical_product import RawUnits
 from eoreader.stac import CENTER_WV, FWHM, GSD, ID, NAME
-from eoreader.utils import DATETIME_FMT, EOREADER_NAME, simplify
+from eoreader.utils import simplify
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
@@ -70,6 +70,20 @@ class S2TheiaProduct(OpticalProduct):
     for more information.
     """
 
+    def __init__(
+        self,
+        product_path: Union[str, CloudPath, Path],
+        archive_path: Union[str, CloudPath, Path] = None,
+        output_path: Union[str, CloudPath, Path] = None,
+        remove_tmp: bool = False,
+        **kwargs,
+    ) -> None:
+        # Theia native NODATA is -1
+        self._raw_nodata = -10000
+
+        # Initialization from the super class
+        super().__init__(product_path, archive_path, output_path, remove_tmp, **kwargs)
+
     def _pre_init(self, **kwargs) -> None:
         """
         Function used to pre_init the products
@@ -418,19 +432,18 @@ class S2TheiaProduct(OpticalProduct):
         """
         # -- Manage nodata from Theia band array
         # Theia nodata is already processed
-        theia_nodata = -1.0
         no_data_mask = np.where(
-            band_arr.data == theia_nodata, self._mask_true, self._mask_false
+            band_arr.data == self._raw_nodata, self._mask_true, self._mask_false
         ).astype(np.uint8)
 
         # Open NODATA pixels mask
         edg_mask = self.open_mask(
-            "EDG", band, size=(band_arr.rio.width, band_arr.rio.height)
+            "EDG", band, size=(band_arr.rio.width, band_arr.rio.height), **kwargs
         )
 
         # Open saturated pixels
         sat_mask = self.open_mask(
-            "SAT", band, size=(band_arr.rio.width, band_arr.rio.height)
+            "SAT", band, size=(band_arr.rio.width, band_arr.rio.height), **kwargs
         )
 
         # Combine masks
@@ -439,7 +452,7 @@ class S2TheiaProduct(OpticalProduct):
         # Open defective pixels (optional mask)
         try:
             def_mask = self.open_mask(
-                "DFP", band, size=(band_arr.rio.width, band_arr.rio.height)
+                "DFP", band, size=(band_arr.rio.width, band_arr.rio.height), **kwargs
             )
             mask = mask | def_mask
         except InvalidProductError:
@@ -464,9 +477,8 @@ class S2TheiaProduct(OpticalProduct):
         """
         # -- Manage nodata from Theia band array
         # Theia nodata is already processed
-        theia_nodata = -1.0
         no_data_mask = np.where(
-            band_arr.data == theia_nodata, self._mask_true, self._mask_false
+            band_arr.data == self._raw_nodata, self._mask_true, self._mask_false
         ).astype(np.uint8)
 
         # -- Merge masks
@@ -517,6 +529,7 @@ class S2TheiaProduct(OpticalProduct):
         band: Union[BandNames, str],
         resolution: float = None,
         size: Union[list, tuple] = None,
+        **kwargs,
     ) -> np.ndarray:
         """
         Open a Sentinel-2 THEIA mask as a numpy array.
@@ -581,16 +594,17 @@ class S2TheiaProduct(OpticalProduct):
         mask_path = self.get_mask_path(mask_id, res_id)
 
         # Open SAT band
-        mask, _ = rasters_rio.read(
+        mask = utils.read(
             mask_path,
             resolution=resolution,
             size=size,
             resampling=Resampling.nearest,  # Nearest to keep the flags
             masked=False,
-        )
+            **kwargs,
+        ).astype(np.uint8)
 
         if mask_id in ["SAT", "DFP"]:
-            bit_mask = rasters_rio.read_bit_array(mask, bit_id)
+            bit_mask = rasters.read_bit_array(mask, bit_id)
         else:
             bit_mask = mask
 
