@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022, SERTIT-ICube - France, https:#sertit.unistra.fr/
+# Copyright 2023, SERTIT-ICube - France, https:#sertit.unistra.fr/
 # This file is part of eoreader project
 #     https:#github.com/sertit/eoreader
 #
@@ -32,7 +32,7 @@ from cloudpathlib import CloudPath
 from rasterio.enums import Resampling
 from sertit import files, rasters, rasters_rio
 
-from eoreader import cache, utils
+from eoreader import EOREADER_NAME, cache, utils
 from eoreader.bands import (
     BLUE,
     CA,
@@ -62,7 +62,6 @@ from eoreader.bands import (
 from eoreader.exceptions import InvalidTypeError
 from eoreader.products import S3DataType, S3Product, S3ProductType
 from eoreader.stac import CENTER_WV, DESCRIPTION, FWHM, GSD, ID, NAME
-from eoreader.utils import EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
@@ -118,8 +117,6 @@ class S3OlciProduct(S3Product):
             product_path, archive_path, output_path, remove_tmp, **kwargs
         )  # Order is important here, gcps NEED to be after this
 
-        self._gcps = []
-
     def _get_preprocessed_band_path(
         self,
         band: Union[BandNames, str],
@@ -451,21 +448,6 @@ class S3OlciProduct(S3Product):
         }
         self.bands.map_bands(olci_bands)
 
-    def _create_gcps(self) -> None:
-        """
-        Create the GCPs sequence
-        """
-
-        # Compute only ig needed
-        if not self._gcps:
-            # Open lon/lat/alt files to populate the GCPs
-            lat = self._read_nc(self._geo_file, self._lat_nc_name)
-            lon = self._read_nc(self._geo_file, self._lon_nc_name)
-            alt = self._read_nc(self._geo_file, self._alt_nc_name)
-
-            # Create GCPs
-            self._gcps = utils.create_gcps(lon, lat, alt)
-
     def get_raw_band_paths(self, **kwargs) -> dict:
         """
         Return the raw band paths.
@@ -735,15 +717,14 @@ class S3OlciProduct(S3Product):
         )
 
         # Open flag file
-        qual_arr, _ = rasters_rio.read(
+        qual_arr = utils.read(
             qual_flags_path,
             size=(band_arr.rio.width, band_arr.rio.height),
             resampling=Resampling.nearest,  # Nearest to keep the flags
             masked=False,
-        )
-        invalid, sat = rasters.read_bit_array(
-            qual_arr.astype(np.uint32), [invalid_id, sat_band_id]
-        )
+            **kwargs,
+        ).astype(np.uint32)
+        invalid, sat = rasters.read_bit_array(qual_arr, [invalid_id, sat_band_id])
 
         # Get nodata mask
         no_data = np.where(np.isnan(band_arr.data), self._mask_true, self._mask_false)
