@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2023, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -48,13 +48,13 @@ from sertit.misc import ListEnum
 from sertit.rasters import MAX_CORES
 from shapely.geometry import Polygon, box
 
-from eoreader import cache, utils
+from eoreader import DATETIME_FMT, EOREADER_NAME, cache, utils
 from eoreader.bands import BandNames, SpectralBandNames
 from eoreader.exceptions import InvalidProductError
 from eoreader.products import OpticalProduct
 from eoreader.products.optical.optical_product import RawUnits
 from eoreader.reader import Constellation
-from eoreader.utils import DATETIME_FMT, EOREADER_NAME, simplify
+from eoreader.utils import simplify
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
@@ -106,7 +106,6 @@ class S3Product(OpticalProduct):
         **kwargs,
     ) -> None:
         self._data_type = None
-        self._gcps = None
 
         # Radiance bands
         self._radiance_file = None
