@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2023, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -22,7 +22,7 @@ Sentinel-3 SLSTR products
     -> use xr.open_dataset that manages that correctly
 """
 import logging
-from collections import defaultdict, namedtuple
+from collections import namedtuple
 from enum import unique
 from functools import reduce
 from pathlib import Path
@@ -33,10 +33,10 @@ import xarray as xr
 from cloudpathlib import CloudPath
 from rasterio import features
 from rasterio.enums import Resampling
-from sertit import files, rasters, rasters_rio
+from sertit import files, rasters
 from sertit.misc import ListEnum
 
-from eoreader import cache, utils
+from eoreader import EOREADER_NAME, cache, utils
 from eoreader.bands import (
     ALL_CLOUDS,
     CIRRUS,
@@ -63,7 +63,6 @@ from eoreader.keywords import CLEAN_OPTICAL, SLSTR_RAD_ADJUST, SLSTR_STRIPE, SLS
 from eoreader.products import S3DataType, S3Product, S3ProductType
 from eoreader.products.optical.optical_product import DEF_CLEAN_METHOD, CleanMethod
 from eoreader.stac import ASSET_ROLE, BT, CENTER_WV, DESCRIPTION, FWHM, GSD, ID, NAME
-from eoreader.utils import EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
@@ -261,7 +260,6 @@ class S3SlstrProduct(S3Product):
             product_path, archive_path, output_path, remove_tmp, **kwargs
         )  # Order is important here, gcps NEED to be after this
 
-        self._gcps = defaultdict(list)
         self._F1_is_f = True
         try:
             self._get_raw_band_path(F1)
@@ -688,24 +686,6 @@ class S3SlstrProduct(S3Product):
         # Return the prefix
         return f"{stripe.value}{view.value}"
 
-    def _create_gcps(self, suffix: str) -> None:
-        """
-        Create the GCPs sequence (WGS84)
-        """
-        if suffix not in self._gcps and not self._gcps[suffix]:
-            geo_file = self._replace(self._geo_file, suffix=suffix)
-            lon_nc_name = self._replace(self._lon_nc_name, suffix=suffix)
-            lat_nc_name = self._replace(self._lat_nc_name, suffix=suffix)
-            alt_nc_name = self._replace(self._alt_nc_name, suffix=suffix)
-
-            # Open cartesian files to populate the GCPs
-            lat = self._read_nc(geo_file, lat_nc_name)
-            lon = self._read_nc(geo_file, lon_nc_name)
-            alt = self._read_nc(geo_file, alt_nc_name)
-
-            # Create GCPs
-            self._gcps[suffix] = utils.create_gcps(lon, lat, alt)
-
     def _tie_to_img(self, tie_arr: np.ndarray, suffix: str) -> np.ndarray:
         """
         Convert an image sampled on the tie point grid (tx) to the wanted gris, given by the suffix
@@ -963,12 +943,13 @@ class S3SlstrProduct(S3Product):
         )
 
         # Open flag file
-        qual_arr, _ = rasters_rio.read(
+        qual_arr = utils.read(
             qual_flags_path,
             size=(band_arr.rio.width, band_arr.rio.height),
             resampling=Resampling.nearest,  # Nearest to keep the flags
             masked=False,
-        )
+            **kwargs,
+        ).astype(np.uint8)
 
         # Set no data for everything that caused an exception (3 and more)
         exception = np.where(qual_arr >= 3, self._mask_true, self._mask_false)
@@ -1065,6 +1046,7 @@ class S3SlstrProduct(S3Product):
                 size=size,
                 resampling=Resampling.nearest,
                 masked=False,
+                **kwargs,
             ).astype(np.uint16)
 
             # Get nodata mask
