@@ -41,10 +41,11 @@ from sertit.snap import MAX_CORES
 
 from eoreader import EOREADER_NAME, utils
 from eoreader.bands import BandNames
-from eoreader.env_vars import DEM_PATH
+from eoreader.env_vars import DEM_PATH, TILE_SIZE
 from eoreader.exceptions import InvalidProductError
 from eoreader.keywords import DEM_KW
 from eoreader.products import OpticalProduct
+from eoreader.utils import DEFAULT_TILE_SIZE
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
@@ -361,7 +362,7 @@ class VhrProduct(OpticalProduct):
                     )
 
                 # Read band
-                LOGGER.debug(f"Reading warped {band.name}...")
+                LOGGER.debug(f"Reading warped {band.name}.")
                 band_arr = utils.read(
                     reproj_path,
                     resolution=resolution,
@@ -370,7 +371,6 @@ class VhrProduct(OpticalProduct):
                     indexes=[self.bands[band].id],
                     **kwargs,
                 )
-                LOGGER.debug(f"...Warped {band.name} read.")
 
             # Manage the case if we open a simple band (EOReader processed bands)
             elif dst.count == 1:
@@ -575,18 +575,25 @@ class VhrProduct(OpticalProduct):
             )
 
             vrt_options = {
-                "resampling": Resampling.bilinear,
                 "crs": self.crs(),
                 "transform": utm_tr,
                 "height": utm_h,
                 "width": utm_w,
+                # TODO: go nearest to speed up results ?
+                "resampling": Resampling.bilinear,
                 "nodata": self._raw_nodata,
+                # Float32 is the max possible
+                "warp_mem_limit": 32
+                * int(os.getenv(TILE_SIZE, DEFAULT_TILE_SIZE)) ** 2
+                / 1e6,
+                "dtype": src.meta["dtype"],
+                "num_threads": MAX_CORES,
             }
-
-            with WarpedVRT(src, **vrt_options) as vrt:
-                # At this point 'vrt' is a full dataset with dimensions,
-                # CRS, and spatial extent matching 'vrt_options'.
-                rio_shutil.copy(vrt, reproj_path, driver="vrt")
+            with rasterio.Env(
+                **{"GDAL_NUM_THREADS": "ALL_CPUS", "NUM_THREADS": "ALL_CPUS"}
+            ):
+                with WarpedVRT(src, **vrt_options) as vrt:
+                    rio_shutil.copy(vrt, reproj_path, driver="vrt")
 
     def _get_default_utm_band(
         self, resolution: float = None, size: Union[list, tuple] = None
