@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2023, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -30,7 +30,7 @@ from abc import abstractmethod
 from enum import unique
 from io import BytesIO
 from pathlib import Path
-from typing import Callable, Tuple, Union
+from typing import Tuple, Union
 from zipfile import ZipFile
 
 import geopandas as gpd
@@ -41,33 +41,42 @@ import xarray as xr
 from affine import Affine
 from cloudpathlib import AnyPath, CloudPath
 from lxml import etree, html
+from rasterio import shutil as rio_shutil
 from rasterio import transform, warp
 from rasterio.crs import CRS
 from rasterio.enums import Resampling
+from rasterio.vrt import WarpedVRT
 from sertit import files, rasters, strings, xml
 from sertit.misc import ListEnum
-from sertit.snap import MAX_CORES
 
-from eoreader import cache, utils
+from eoreader import EOREADER_NAME, cache, utils
 from eoreader.bands import (
     DEM,
     HILLSHADE,
+    NEEDED_BANDS,
     SLOPE,
     BandNames,
+    compute_index,
     indices,
     is_clouds,
     is_dem,
     is_index,
-    is_sat_band,
+    is_sar_band,
+    is_spectral_band,
     to_band,
     to_str,
 )
 from eoreader.env_vars import CI_EOREADER_BAND_FOLDER, DEM_PATH
-from eoreader.exceptions import InvalidProductError, InvalidTypeError
+from eoreader.exceptions import (
+    InvalidBandError,
+    InvalidIndexError,
+    InvalidProductError,
+    InvalidTypeError,
+)
 from eoreader.keywords import DEM_KW, HILLSHADE_KW, SLOPE_KW
 from eoreader.reader import Constellation, Reader
 from eoreader.stac import StacItem
-from eoreader.utils import EOREADER_NAME, simplify
+from eoreader.utils import UINT16_NODATA, simplify
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 PRODUCT_FACTORY = Reader()
@@ -495,6 +504,40 @@ class Product:
 
         return date
 
+    def _construct_band_path(
+        self,
+        band: BandNames,
+        resolution: float = None,
+        size: Union[list, tuple] = None,
+        writable: bool = False,
+        **kwargs,
+    ) -> Union[CloudPath, Path]:
+        """
+        Get cloud band path.
+
+        Args:
+            band (BandNames): Wanted band
+            resolution (float): Band resolution in meters
+            writable (bool): True if we want the band folder to be writeable
+            kwargs: Additional arguments
+
+        Returns:
+            Union[CloudPath, Path]: Clean band path
+        """
+        # Manage resolution
+        if resolution is None:
+            if size is not None:
+                resolution = self._resolution_from_size(size)
+            else:
+                resolution = self.resolution
+
+        # Convert to str
+        res_str = self._resolution_to_str(resolution)
+
+        return self._get_band_folder(writable).joinpath(
+            f"{self.condensed_name}_{to_str(band)[0]}_{res_str.replace('.', '-')}.tif",
+        )
+
     @abstractmethod
     def get_default_band_path(self, **kwargs) -> Union[CloudPath, Path]:
         """
@@ -771,6 +814,220 @@ class Product:
         """
         raise NotImplementedError
 
+    def load(
+        self,
+        bands: Union[list, BandNames, str],
+        resolution: float = None,
+        size: Union[list, tuple] = None,
+        **kwargs,
+    ) -> dict:
+        """
+        Open the bands and compute the wanted index.
+
+        - For Optical data:
+            The bands will be purged of nodata and invalid pixels (if specified with the CLEAN_OPTICAL keyword),
+            the nodata will be set to -9999 and the bands will be DataArrays in float32.
+
+        - For SAR data:
+            The bands will be purged of nodata (not over the sea),
+            the nodata will be set to 0 to respect SNAP's behavior and the bands will be DataArray in float32.
+
+        Bands that come out this function at the same time are collocated and therefore have the same shapes.
+        This can be broken if you load data separately. Its is best to always load DEM data with some real bands.
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> from eoreader.bands import *
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> bands = prod.load([GREEN, NDVI], resolution=20)
+
+        Args:
+            bands (Union[list, BandNames, str]): Band list
+            resolution (float): Resolution of the band, in meters
+            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
+            kwargs: Other arguments used to load bands
+
+        Returns:
+            dict: {band_name, band xarray}
+        """
+        # Check if all bands are valid
+        bands = to_band(bands)
+
+        for band in bands:
+            assert self.has_band(band), f"{self.name} has not a {to_str(band)[0]} band."
+
+        if not resolution and not size:
+            resolution = self.resolution
+
+        # Load bands (only once ! and convert the bands to be loaded to correct format)
+        unique_bands = list(set(to_band(bands)))
+        band_dict = self._load(unique_bands, resolution, size, **kwargs)
+
+        # Manage the case of arrays of different size -> collocate arrays if needed
+        band_dict = self._collocate_bands(band_dict)
+
+        # Convert to xarray dataset when all the bands have the same size
+        # TODO: cannot convert as we have non-string index
+        # xds = xr.Dataset(band_dict)
+
+        # Sort bands to the asked order
+        # xds.reindex({"band": bands})
+
+        # Rename all bands and add attributes
+        for key, val in band_dict.items():
+            band_dict[key] = self._update_attrs(val, key, **kwargs)
+
+        return band_dict
+
+    def _load(
+        self,
+        bands: list,
+        resolution: float = None,
+        size: Union[list, tuple] = None,
+        **kwargs,
+    ) -> dict:
+        """
+        Core function loading optical data bands
+
+        Args:
+            bands (list): Band list
+            resolution (float): Resolution of the band, in meters
+            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
+            kwargs: Other arguments used to load bands
+
+        Returns:
+            Dictionary {band_name, band_xarray}
+        """
+        band_list = []
+        index_list = []
+        dem_list = []
+        clouds_list = []
+
+        # Check if everything is valid
+        for band in bands:
+            if is_index(band):
+                if self._has_index(band):
+                    if band in indices.EOREADER_ALIASES:
+                        from warnings import warn
+
+                        warn(
+                            "Aliases of Awesome Spectral Indices won't be available in future versions of EOReader. "
+                            f"Please use {indices.EOREADER_ALIASES[band]} instead of {band}",
+                            category=DeprecationWarning,
+                        )
+                    index_list.append(band)
+                else:
+                    raise InvalidIndexError(
+                        f"{band} cannot be computed from {self.condensed_name}."
+                    )
+            elif is_sar_band(band):
+                if self.sensor_type == SensorType.SAR:
+                    if not self.has_band(band):
+                        raise InvalidBandError(
+                            f"{band} cannot be retrieved from {self.condensed_name}"
+                        )
+                    else:
+                        band_list.append(band)
+                else:
+                    raise TypeError(
+                        f"You should ask for Optical bands as {self.name} is an optical product."
+                    )
+            elif is_spectral_band(band):
+                if self.sensor_type == SensorType.OPTICAL:
+                    if self.has_band(band):
+                        band_list.append(band)
+                    else:
+                        raise InvalidBandError(
+                            f"{band} cannot be retrieved from {self.condensed_name}."
+                        )
+                else:
+                    raise TypeError(
+                        f"You should ask for SAR bands as {self.name} is a SAR product."
+                    )
+            elif is_dem(band):
+                dem_list.append(band)
+            elif is_clouds(band):
+                if self.sensor_type == SensorType.OPTICAL:
+                    clouds_list.append(band)
+                else:
+                    raise TypeError(
+                        f"You cannot ask for cloud bands as {self.name} is a SAR product."
+                    )
+
+        # Check if DEM is set and exists
+        if dem_list:
+            self._check_dem_path(bands, **kwargs)
+
+        # Get all bands to be open
+        bands_to_load = band_list.copy()
+        for idx in index_list:
+            bands_to_load += NEEDED_BANDS[idx]
+
+        # Load band arrays (only keep unique bands: open them only one time !)
+        unique_bands = list(set(bands_to_load))
+        bands_dict = {}
+        if unique_bands:
+            LOGGER.debug(f"Loading bands {to_str(unique_bands)}")
+            loaded_bands = self._load_bands(
+                unique_bands, resolution=resolution, size=size, **kwargs
+            )
+
+            # Add bands
+            bands_dict.update({band: loaded_bands[band] for band in band_list})
+
+            # Compute index (they conserve the nodata)
+            if index_list:
+                LOGGER.debug(f"Loading indices {to_str(index_list)}")
+                bands_dict.update(
+                    self._load_spectral_indices(
+                        index_list,
+                        loaded_bands,
+                        resolution=resolution,
+                        size=size,
+                        **kwargs,
+                    )
+                )
+
+        # Add DEM
+        if dem_list:
+            LOGGER.debug(f"Loading DEM bands {to_str(dem_list)}")
+            bands_dict.update(
+                self._load_dem(dem_list, resolution=resolution, size=size, **kwargs)
+            )
+
+        # Add Clouds
+        if clouds_list:
+            LOGGER.debug(f"Loading Cloud bands {to_str(clouds_list)}")
+            bands_dict.update(
+                self._load_clouds(
+                    clouds_list, resolution=resolution, size=size, **kwargs
+                )
+            )
+
+        return bands_dict
+
+    def _load_clouds(
+        self,
+        bands: list,
+        resolution: float = None,
+        size: Union[list, tuple] = None,
+        **kwargs,
+    ) -> dict:
+        """
+        Load cloud files as xarrays.
+
+        Args:
+            bands (list): List of the wanted bands
+            resolution (int): Band resolution in meters
+            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
+            kwargs: Additional arguments
+        Returns:
+            dict: Dictionary {band_name, band_xarray}
+        """
+        raise NotImplementedError
+
     @abstractmethod
     def _load_bands(
         self,
@@ -792,6 +1049,45 @@ class Product:
         """
         raise NotImplementedError
 
+    def _load_spectral_indices(
+        self,
+        index_list: list,
+        loaded_bands: dict,
+        resolution: Union[float, tuple] = None,
+        size: Union[list, tuple] = None,
+        **kwargs,
+    ) -> dict:
+        """
+        Load cloud files as xarrays.
+
+        Args:
+            bands (list): List of the wanted bands
+            resolution (int): Band resolution in meters
+            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
+            kwargs: Additional arguments
+        Returns:
+            dict: Dictionary {band_name, band_xarray}
+        """
+        band_dict = {}
+        for idx in index_list:
+            idx_path = self._construct_band_path(
+                idx, resolution, size, writable=False, **kwargs
+            )
+            if idx_path.is_file():
+                band_dict[idx] = utils.read(idx_path)
+            else:
+                idx_arr = compute_index(index=idx, bands=loaded_bands).rename(idx)
+                idx_arr.attrs["long_name"] = idx
+
+                # Write on disk
+                idx_path = self._construct_band_path(
+                    idx, resolution, size, writable=True, **kwargs
+                )
+                utils.write(idx_arr, idx_path)
+                band_dict[idx] = idx_arr
+
+        return band_dict
+
     def _load_dem(
         self,
         band_list: list,
@@ -843,101 +1139,7 @@ class Product:
 
         return dem_bands
 
-    def load(
-        self,
-        bands: Union[list, BandNames, Callable],
-        resolution: float = None,
-        size: Union[list, tuple] = None,
-        **kwargs,
-    ) -> dict:
-        """
-        Open the bands and compute the wanted index.
-
-        - For Optical data:
-            The bands will be purged of nodata and invalid pixels (if specified with the CLEAN_OPTICAL keyword),
-            the nodata will be set to -9999 and the bands will be DataArrays in float32.
-
-        - For SAR data:
-            The bands will be purged of nodata (not over the sea),
-            the nodata will be set to 0 to respect SNAP's behavior and the bands will be DataArray in float32.
-
-        Bands that come out this function at the same time are collocated and therefore have the same shapes.
-        This can be broken if you load data separately. Its is best to always load DEM data with some real bands.
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> from eoreader.bands import *
-            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-            >>> prod = Reader().open(path)
-            >>> bands = prod.load([GREEN, NDVI], resolution=20)
-
-        Args:
-            bands (Union[list, BandNames, Callable]): Band list
-            resolution (float): Resolution of the band, in meters
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-            kwargs: Other arguments used to load bands
-
-        Returns:
-            dict: {band_name, band xarray}
-        """
-
-        # Check if all bands are valid
-        bands = to_band(bands)
-
-        for band in bands:
-            try:
-                band_name = band.value
-            except AttributeError:
-                band_name = band
-            assert self.has_band(band), f"{self.name} has not a {band_name} band."
-
-        if not resolution and not size:
-            resolution = self.resolution
-
-        # Load bands (only once ! and convert the bands to be loaded to correct format)
-        unique_bands = list(set(to_band(bands)))
-        band_dict = self._load(unique_bands, resolution, size, **kwargs)
-
-        # Manage the case of arrays of different size -> collocate arrays if needed
-        band_dict = self._collocate_bands(band_dict)
-
-        # Convert to xarray dataset when all the bands have the same size
-        # TODO: cannot convert as we have non-string index
-        # xds = xr.Dataset(band_dict)
-
-        # Sort bands to the asked order
-        # xds.reindex({"band": bands})
-
-        # Rename all bands and add attributes
-        for key, val in band_dict.items():
-            band_dict[key] = self._update_attrs(val, key, **kwargs)
-
-        return band_dict
-
-    @abstractmethod
-    def _load(
-        self,
-        bands: list,
-        resolution: float = None,
-        size: Union[list, tuple] = None,
-        **kwargs,
-    ) -> dict:
-        """
-        Core function loading data bands
-
-        Args:
-            bands (list): Band list
-            resolution (float): Resolution of the band, in meters
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-            kwargs: Other arguments used to load bands
-
-        Returns:
-            Dictionary {band_name, band_xarray}
-        """
-        raise NotImplementedError
-
-    def has_band(self, band: Union[BandNames, Callable]) -> bool:
+    def has_band(self, band: Union[BandNames, str]) -> bool:
         """
         Does this product has the specified band ?
 
@@ -966,7 +1168,7 @@ class Product:
             True
 
         Args:
-            band (Union[BandNames, Callable]): EOReader band (optical, SAR, clouds, DEM)
+            band (Union[BandNames, str]): EOReader band (optical, SAR, clouds, DEM)
 
         Returns:
             bool: True if the products has the specified band
@@ -987,7 +1189,7 @@ class Product:
 
         return has_band
 
-    def has_bands(self, bands: Union[list, BandNames, Callable]) -> bool:
+    def has_bands(self, bands: Union[list, BandNames, str]) -> bool:
         """
         Does this product has the specified bands ?
 
@@ -1001,7 +1203,7 @@ class Product:
         See :code:`has_bands` for a code example.
 
         Args:
-            bands (Union[list, BandNames, Callable]): EOReader bands (optical, SAR, clouds, DEM)
+            bands (Union[list, BandNames, str]): EOReader bands (optical, SAR, clouds, DEM)
 
         Returns:
             bool: True if the products has the specified band
@@ -1027,7 +1229,7 @@ class Product:
         """
         raise NotImplementedError
 
-    def _has_index(self, idx: Callable) -> bool:
+    def _has_index(self, idx: str) -> bool:
         """
         Cen the specified index be computed from this product ?
 
@@ -1041,7 +1243,7 @@ class Product:
             True
 
         Args:
-            idx (Callable): Index
+            idx (str): Index
 
         Returns:
             bool: True if the specified index can be computed with this product's bands
@@ -1222,7 +1424,7 @@ class Product:
         Returns:
             Union[Path, CloudPath]: DEM path (as a VRT)
         """
-        dem_name = f"{self.condensed_name}_DEM_{files.get_filename(dem_path)}.tif"
+        dem_name = f"{self.condensed_name}_DEM_{files.get_filename(dem_path)}.vrt"
 
         warped_dem_path, warped_dem_exists = self._get_out_path(dem_name)
         if warped_dem_exists:
@@ -1283,36 +1485,20 @@ class Product:
                         resolution=resolution,
                     )
 
-                # Get empty output
-                reprojected_array = np.zeros(
-                    (dem_ds.count, out_h, out_w), dtype=np.float32
-                )
-
-                # Write reprojected DEM: here do not use utils.write()
-                out_meta = {
-                    "driver": "GTiff",
-                    "dtype": reprojected_array.dtype,
-                    "nodata": self.nodata,
-                    "width": out_w,
-                    "height": out_h,
-                    "count": dem_ds.count,
+                vrt_options = {
+                    "resampling": resampling,
                     "crs": self.crs(),
                     "transform": dst_tr,
+                    "height": out_h,
+                    "width": out_w,
+                    "nodata": self.nodata,
+                    "dtype": "float32",
                 }
-                with rasterio.open(str(warped_dem_path), "w", **out_meta) as out_dst:
-                    out_dst.write(reprojected_array)
 
-                    # Reproject
-                    warp.reproject(
-                        source=rasterio.band(dem_ds, range(1, dem_ds.count + 1)),
-                        destination=rasterio.band(out_dst, range(1, out_dst.count + 1)),
-                        resampling=resampling,
-                        num_threads=MAX_CORES,
-                        dst_transform=dst_tr,
-                        dst_crs=self.crs(),
-                        src_crs=dem_ds.crs,
-                        src_transform=dem_ds.transform,
-                    )
+                with WarpedVRT(dem_ds, **vrt_options) as vrt:
+                    # At this point 'vrt' is a full dataset with dimensions,
+                    # CRS, and spatial extent matching 'vrt_options'.
+                    rio_shutil.copy(vrt, warped_dem_path, driver="vrt")
 
         return warped_dem_path
 
@@ -1443,82 +1629,17 @@ class Product:
         Returns:
             xr.DataArray: Stack as a DataArray
         """
-        if not isinstance(bands, list):
-            bands = [bands]
-
-        # Ensure the bands are not in strings (otherwise will bug in Dataset conversion)
         bands = to_band(bands)
 
-        if not resolution and not size:
-            resolution = self.resolution
-
         # Create the analysis stack
         band_dict = self.load(bands, resolution=resolution, size=size, **kwargs)
 
-        # Convert into dataset with str as names
-        LOGGER.debug("Stacking")
-        data_vars = {}
-        coords = band_dict[bands[0]].coords
-        for key in bands:
-            data_vars[to_str(key)[0]] = (
-                band_dict[key].coords.dims,
-                band_dict[key].data,
-            )
-
-            # Set memory free (for big stacks)
-            band_dict[key].close()
-            band_dict[key] = None
-
-        # Create dataset, with dims well-ordered
-        stack = (
-            xr.Dataset(
-                data_vars=data_vars,
-                coords=coords,
-            )
-            .to_stacked_array(new_dim="z", sample_dims=("x", "y"))
-            .transpose("z", "y", "x")
-        )
-
-        # Save as integer
-        dtype = np.float32
+        # Stack bands
         if save_as_int:
-            default_nodata = 65535
-            scale = 10000
-            stack_min = np.min(stack)
-            if stack_min < -0.1:
-                LOGGER.warning(
-                    "Cannot convert the stack to uint16 as it has negative values (< -0.1). Keeping it in float32."
-                )
-            else:
-                if stack_min < 0:
-                    LOGGER.warning(
-                        "Small negative values ]-0.1, 0] have been found. Clipping to 0."
-                    )
-                    stack = stack.copy(data=np.clip(stack.data, a_min=0, a_max=None))
-
-                # Scale to uint16, fill nan and convert to uint16
-                dtype = np.uint16
-                nodata = kwargs.get("nodata", default_nodata)  # Can be 0
-                for b_id, band in enumerate(bands):
-                    # SCALING
-                    # NOT ALL bands need to be scaled, only:
-                    # - Satellite bands
-                    # - index
-                    if is_sat_band(band) or is_index(band):
-                        if np.max(stack[b_id, ...]) > default_nodata / scale:
-                            LOGGER.debug(
-                                "Band not in reflectance, keeping them as is (the values will be rounded)"
-                            )
-                        else:
-                            stack[b_id, ...] = stack[b_id, ...] * scale
-
-                    # Fill no data (done here to avoid RAM saturation)
-                    stack[b_id, ...] = stack[b_id, ...].fillna(nodata)
-
-        if dtype == np.float32:
-            # Set nodata if needed (NaN values are already set)
-            if stack.rio.encoded_nodata != self.nodata:
-                stack = stack.rio.write_nodata(self.nodata, encoded=True, inplace=True)
+            nodata = kwargs.pop("nodata", UINT16_NODATA)
+        else:
+            nodata = kwargs.pop("nodata", self.nodata)
+        stack, dtype = utils.stack_dict(bands, band_dict, save_as_int, nodata, **kwargs)
 
         # Update stack's attributes
         stack = self._update_attrs(stack, bands, **kwargs)
@@ -1529,7 +1650,8 @@ class Product:
             stack_path = AnyPath(stack_path)
             if not stack_path.parent.exists():
                 os.makedirs(str(stack_path.parent), exist_ok=True)
-            utils.write(stack, stack_path, dtype=dtype, **kwargs)
+
+            utils.write(stack, stack_path, dtype=dtype, nodata=nodata, **kwargs)
 
         return stack
 
@@ -1543,6 +1665,9 @@ class Product:
         Args:
             xarr (xr.DataArray): Array whose attributes need an update
             bands (list): Array name (as a str or a list)
+
+        Returns:
+            xr.DataArray: Updated array/dataset
         """
         raise NotImplementedError
 
